@@ -8,9 +8,9 @@ from xlsxwriter.worksheet import Worksheet
 
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.reference import (
-    ParentReqReference,
-    FileReference,
     BibReference,
+    FileReference,
+    ParentReqReference,
 )
 from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.backend.sdoc.models.type_system import ReferenceType
@@ -28,18 +28,10 @@ EXPORT_COLUMNS = [
         "name": "uid",
         "header": "UID",
     },
-    # {
-    #     "name": "title",
-    #     "header": "TITLE",
-    # },
     {
         "name": "statement",
         "header": "STATEMENT",
     },
-    # {
-    #     "name": "rationale",
-    #     "header": "RATIONALE",
-    # },
 ]
 
 
@@ -94,7 +86,7 @@ class ExcelGenerator:
                 for node in traceability_index.get_document_iterator(
                     document
                 ).all_content():
-                    if not node.is_requirement or not node.uid:
+                    if not node.is_requirement or not node.reserved_uid:
                         # only export the requirements with uid
                         continue
 
@@ -134,7 +126,7 @@ class ExcelGenerator:
                                 for comment in node.comments:
                                     if len(value) > 0:
                                         value += "\n----------\n"
-                                    value += comment.get_comment()
+                                    value += comment
                                 worksheet.write(row, idx, value)
                                 if (
                                     value
@@ -162,7 +154,7 @@ class ExcelGenerator:
                                         value += (
                                             ref.ref_type
                                             + ": "
-                                            + ref.file_entry.file_path
+                                            + ref.get_posix_path()
                                             + "\n"
                                         )
                                     elif isinstance(ref, BibReference):
@@ -215,7 +207,9 @@ class ExcelGenerator:
                 )
             else:
                 # no requirement with UID
-                print("No requirement with UID, nothing to export into excel")
+                print(  # noqa: T201
+                    "No requirement with UID, nothing to export into excel"
+                )
 
         if row == 1:
             os.unlink(document_out_file)
@@ -227,10 +221,10 @@ class ExcelGenerator:
 
         for content_node in document_contents:
             if isinstance(content_node, Requirement):
-                if content_node.uid:
+                if content_node.reserved_uid:
                     # only export the requirements with uid, allowing tracking
                     row += 1
-                    refs[content_node.uid] = row
+                    refs[content_node.reserved_uid] = row
 
         return refs
 
