@@ -8,26 +8,28 @@ from strictdoc.backend.sdoc.models.fragment import Fragment
 from strictdoc.backend.sdoc.models.fragment_from_file import FragmentFromFile
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
 from strictdoc.backend.sdoc.models.reference import (
-    Reference,
-    ParentReqReference,
+    BibReference,
     FileReference,
+    ParentReqReference,
+    Reference,
 )
 from strictdoc.backend.sdoc.models.requirement import (
-    RequirementComment,
+    CompositeRequirement,
     Requirement,
     RequirementField,
-    CompositeRequirement,
 )
-from strictdoc.backend.sdoc.models.section import Section, FreeText
+from strictdoc.backend.sdoc.models.section import FreeText, Section
 from strictdoc.backend.sdoc.models.type_system import (
-    GrammarElementFieldString,
-    GrammarElementFieldSingleChoice,
+    BibEntry,
+    FileEntry,
     GrammarElementFieldMultipleChoice,
+    GrammarElementFieldReference,
+    GrammarElementFieldSingleChoice,
+    GrammarElementFieldString,
     GrammarElementFieldTag,
 )
 
 SECTION_MODELS = [
-    RequirementComment,
     Section,
     FragmentFromFile,
     Requirement,
@@ -36,8 +38,11 @@ SECTION_MODELS = [
     Reference,
     ParentReqReference,
     FileReference,
+    BibReference,
     FreeText,
     InlineLink,
+    FileEntry,
+    BibEntry,
 ]
 
 DOCUMENT_MODELS = [
@@ -49,6 +54,7 @@ DOCUMENT_MODELS = [
     GrammarElementFieldSingleChoice,
     GrammarElementFieldMultipleChoice,
     GrammarElementFieldTag,
+    GrammarElementFieldReference,
 ]
 DOCUMENT_MODELS.extend(SECTION_MODELS)
 
