@@ -5,21 +5,21 @@ from strictdoc.backend.sdoc.models.document_config import DocumentConfig
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
 from strictdoc.backend.sdoc.models.reference import (
     BibReference,
-    Reference,
     FileReference,
     ParentReqReference,
+    Reference,
 )
 from strictdoc.backend.sdoc.models.requirement import (
-    Requirement,
     CompositeRequirement,
+    Requirement,
 )
-from strictdoc.backend.sdoc.models.section import Section, FreeText
+from strictdoc.backend.sdoc.models.section import FreeText, Section
 from strictdoc.backend.sdoc.models.type_system import (
-    GrammarElementFieldString,
-    GrammarElementFieldSingleChoice,
     GrammarElementFieldMultipleChoice,
-    GrammarElementFieldTag,
     GrammarElementFieldReference,
+    GrammarElementFieldSingleChoice,
+    GrammarElementFieldString,
+    GrammarElementFieldTag,
     RequirementFieldType,
 )
 from strictdoc.core.document_iterator import DocumentCachingIterator
@@ -146,7 +146,7 @@ class SDWriter:
 
         return output
 
-    def _print_section(self, section):
+    def _print_section(self, section: Section):
         assert isinstance(section, Section)
         output = ""
         output += "[SECTION]"
@@ -157,9 +157,9 @@ class SDWriter:
             output += section.uid
             output += "\n"
 
-        if section.level:
+        if section.custom_level:
             output += "LEVEL: "
-            output += section.level
+            output += section.custom_level
             output += "\n"
 
         output += "TITLE: "
@@ -214,12 +214,13 @@ class SDWriter:
                             output += "\n"
                         elif isinstance(reference, FileReference):
                             ref: FileReference = reference
-                            if ref.file_entry.file_format:
+                            file_format = ref.get_file_format()
+                            if file_format:
                                 output += "  FORMAT: "
-                                output += ref.file_entry.file_format
+                                output += file_format
                                 output += "\n"
                             output += "  VALUE: "
-                            output += ref.file_entry.file_path
+                            output += ref.get_posix_path()
                             output += "\n"
                         elif isinstance(reference, ParentReqReference):
                             ref: ParentReqReference = reference
