@@ -7,8 +7,8 @@ from strictdoc.cli.cli_arg_parser import ExportCommandConfig
 from strictdoc.core.document_meta import DocumentMeta
 from strictdoc.core.document_tree import DocumentTree
 from strictdoc.core.file_tree import (
-    FileTree,
     FileFinder,
+    FileTree,
     PathFinder,
 )
 from strictdoc.helpers.textx import drop_textx_meta
@@ -27,7 +27,7 @@ class DocumentFinder:
                     "Provided path is neither a single file or a folder: "
                     f"'{paths_to_files_or_doc}'"
                 )
-                print(err)
+                print(err)  # noqa: T201
                 sys.exit(1)
 
         file_tree, asset_dirs = DocumentFinder._build_file_tree(config)
@@ -162,7 +162,7 @@ class DocumentFinder:
             file_tree_structure = FileFinder.find_files_with_extensions(
                 root_path=path_to_doc_root,
                 ignored_dirs=[config.output_dir],
-                extensions={".sdoc"},
+                extensions=[".sdoc"],
             )
             root_trees.append(file_tree_structure)
 
