@@ -1,6 +1,8 @@
+from strictdoc import __version__
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.export.html.document_type import DocumentType
 from strictdoc.export.html.html_templates import HTMLTemplates
+from strictdoc.export.html.renderers.link_renderer import LinkRenderer
 
 
 class DocumentHTMLGenerator:
@@ -12,7 +14,7 @@ class DocumentHTMLGenerator:
         document: Document,
         traceability_index,
         markup_renderer,
-        link_renderer,
+        link_renderer: LinkRenderer,
         standalone: bool,
     ):
         output = ""
@@ -21,8 +23,6 @@ class DocumentHTMLGenerator:
             "single_document/document.jinja.html"
         )
 
-        root_path = document.meta.get_root_path_prefix()
-        static_path = f"{root_path}/_static"
         document_iterator = traceability_index.get_document_iterator(document)
 
         output += template.render(
@@ -33,9 +33,8 @@ class DocumentHTMLGenerator:
             renderer=markup_renderer,
             standalone=standalone,
             document_type=DocumentType.document(),
-            root_path=root_path,
-            static_path=static_path,
             document_iterator=document_iterator,
+            strictdoc_version=__version__,
         )
 
         return output
