@@ -2,8 +2,10 @@ import os
 from functools import partial
 from pathlib import Path
 
+from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.cli.cli_arg_parser import ExportCommandConfig, ExportMode
 from strictdoc.core.document_meta import DocumentMeta
+from strictdoc.core.project_config import ProjectConfig, ProjectFeature
 from strictdoc.core.source_tree import SourceTree
 from strictdoc.core.traceability_index import TraceabilityIndex
 from strictdoc.export.html.generators.document import DocumentHTMLGenerator
@@ -39,30 +41,29 @@ class HTMLGenerator:
     @staticmethod
     def export_tree(
         *,
+        project_config: ProjectConfig,
         config: ExportCommandConfig,
         traceability_index: TraceabilityIndex,
         parallelizer,
     ):  # pylint: disable=too-many-arguments,too-many-statements
-
-        link_renderer = LinkRenderer(config.output_html_root)
-
         # Export document tree.
-        output_html_static_files = os.path.join(
-            config.output_html_root, "_static"
+        HTMLGenerator.export_document_tree(
+            config=config, traceability_index=traceability_index
         )
-        output_file = os.path.join(config.output_html_root, "index.html")
-        writer = DocumentTreeHTMLGenerator()
-        output = writer.export(config, traceability_index)
-        with open(output_file, "w", encoding="utf8") as file:
-            file.write(output)
 
         # Export StrictDoc's own assets.
+        output_html_static_files = os.path.join(
+            config.output_html_root, config.dir_for_sdoc_assets
+        )
         sync_dir(config.get_static_files_path(), output_html_static_files)
 
         # Export MathJax
-        if config.enable_mathjax:
+        if (
+            project_config.is_feature_activated(ProjectFeature.MATHJAX)
+            or config.enable_mathjax
+        ):
             output_html_mathjax = os.path.join(
-                config.output_html_root, "_static", "mathjax"
+                config.output_html_root, config.dir_for_sdoc_assets, "mathjax"
             )
             Path(output_html_mathjax).mkdir(parents=True, exist_ok=True)
             mathjax_src = os.path.join(
@@ -81,9 +82,9 @@ class HTMLGenerator:
 
         export_binding = partial(
             HTMLGenerator._export_with_performance,
+            project_config,
             config,
             traceability_index=traceability_index,
-            link_renderer=link_renderer,
         )
 
         parallelizer.map(
@@ -91,27 +92,37 @@ class HTMLGenerator:
         )
 
         # Export requirements coverage.
-        requirements_coverage_content = (
-            RequirementsCoverageHTMLGenerator.export(
-                config,
-                traceability_index,
-                link_renderer,
+        if (
+            project_config.is_feature_activated(
+                ProjectFeature.REQUIREMENTS_COVERAGE_SCREEN
             )
-        )
-        output_html_requirements_coverage = os.path.join(
-            config.output_html_root, "requirements_coverage.html"
-        )
-        with open(
-            output_html_requirements_coverage, "w", encoding="utf8"
-        ) as file:
-            file.write(requirements_coverage_content)
+            or config.enable_mathjax
+        ):
+            requirements_coverage_content = (
+                RequirementsCoverageHTMLGenerator.export(
+                    config,
+                    traceability_index,
+                )
+            )
+            output_html_requirements_coverage = os.path.join(
+                config.output_html_root, "requirements_coverage.html"
+            )
+            with open(
+                output_html_requirements_coverage, "w", encoding="utf8"
+            ) as file:
+                file.write(requirements_coverage_content)
 
         # Export source coverage.
-        if config.experimental_enable_file_traceability:
+        if (
+            project_config.is_feature_activated(
+                ProjectFeature.REQUIREMENT_TO_SOURCE_TRACEABILITY
+            )
+            or config.experimental_enable_file_traceability
+        ):
             assert isinstance(
                 traceability_index.document_tree.source_tree, SourceTree
-            )
-            print("Generating source files:")
+            ), traceability_index.document_tree.source_tree
+            print("Generating source files:")  # noqa: T201
             for (
                 source_file
             ) in traceability_index.document_tree.source_tree.source_files:
@@ -125,9 +136,9 @@ class HTMLGenerator:
                         parents=True, exist_ok=True
                     )
                     document_content = SourceFileViewHTMLGenerator.export(
+                        config,
                         source_file,
                         traceability_index,
-                        link_renderer,
                     )
                     with open(
                         source_file.output_file_full_path, "w", encoding="utf-8"
@@ -137,7 +148,6 @@ class HTMLGenerator:
             source_coverage_content = SourceFileCoverageHTMLGenerator.export(
                 config=config,
                 traceability_index=traceability_index,
-                link_renderer=link_renderer,
             )
             output_html_source_coverage = os.path.join(
                 config.output_html_root, "source_coverage.html"
@@ -147,44 +157,48 @@ class HTMLGenerator:
             ) as file:
                 file.write(source_coverage_content)
 
-        print(
+        print(  # noqa: T201
             "Export completed. Documentation tree can be found at:\n"
             f"{config.output_html_root}"
         )
 
     @staticmethod
     def _export_with_performance(
+        project_config: ProjectConfig,
         config: ExportCommandConfig,
         document,
         traceability_index,
-        link_renderer,
     ):
-        if not document.ng_needs_generation:
+        if not config.is_running_on_server and not document.ng_needs_generation:
             with measure_performance(f"Skip: {document.title}"):
                 return
         with measure_performance(f"Published: {document.title}"):
-            HTMLGenerator._export(
+            HTMLGenerator.export_single_document(
+                project_config,
                 config,
                 document,
                 traceability_index,
-                link_renderer,
             )
-        return
 
     @staticmethod
-    def _export(
+    def export_single_document(
+        project_config: ProjectConfig,
         config: ExportCommandConfig,
-        document,
+        document: Document,
         traceability_index,
-        link_renderer,
     ):
         export_mode = config.get_export_mode()
+        assert document.meta is not None
 
         document_meta: DocumentMeta = document.meta
 
         document_output_folder = document_meta.output_document_dir_full_path
         Path(document_output_folder).mkdir(parents=True, exist_ok=True)
 
+        root_path = document.meta.get_root_path_prefix()
+        link_renderer = LinkRenderer(
+            root_path=root_path, static_path=config.dir_for_sdoc_assets
+        )
         markup_renderer = MarkupRenderer.create(
             document.config.markup,
             traceability_index,
@@ -210,42 +224,53 @@ class HTMLGenerator:
                 file.write(document_content)
 
             # Single Document Table pages
-            document_content = DocumentTableHTMLGenerator.export(
-                config,
-                document,
-                traceability_index,
-                markup_renderer,
-                link_renderer,
-            )
-            document_out_file = document_meta.get_html_table_path()
-            with open(document_out_file, "w", encoding="utf8") as file:
-                file.write(document_content)
+            if project_config.is_feature_activated(ProjectFeature.TABLE_SCREEN):
+                document_content = DocumentTableHTMLGenerator.export(
+                    config,
+                    document,
+                    traceability_index,
+                    markup_renderer,
+                    link_renderer,
+                )
+                document_out_file = document_meta.get_html_table_path()
+                with open(document_out_file, "w", encoding="utf8") as file:
+                    file.write(document_content)
 
             # Single Document Traceability pages
-            document_content = DocumentTraceHTMLGenerator.export(
-                config,
-                document,
-                traceability_index,
-                markup_renderer,
-                link_renderer,
-            )
-            document_out_file = document_meta.get_html_traceability_path()
-            with open(document_out_file, "w", encoding="utf8") as file:
-                file.write(document_content)
+            if project_config.is_feature_activated(
+                ProjectFeature.TRACEABILITY_SCREEN
+            ):
+                document_content = DocumentTraceHTMLGenerator.export(
+                    config,
+                    document,
+                    traceability_index,
+                    markup_renderer,
+                    link_renderer,
+                )
+                document_out_file = document_meta.get_html_traceability_path()
+                with open(document_out_file, "w", encoding="utf8") as file:
+                    file.write(document_content)
 
             # Single Document Deep Traceability pages
-            document_content = DocumentDeepTraceHTMLGenerator.export_deep(
-                config,
-                document,
-                traceability_index,
-                markup_renderer,
-                link_renderer,
-            )
-            document_out_file = document_meta.get_html_deep_traceability_path()
-            with open(document_out_file, "w", encoding="utf8") as file:
-                file.write(document_content)
+            if project_config.is_feature_activated(
+                ProjectFeature.DEEP_TRACEABILITY_SCREEN
+            ):
+                document_content = DocumentDeepTraceHTMLGenerator.export_deep(
+                    config,
+                    document,
+                    traceability_index,
+                    markup_renderer,
+                    link_renderer,
+                )
+                document_out_file = (
+                    document_meta.get_html_deep_traceability_path()
+                )
+                with open(document_out_file, "w", encoding="utf8") as file:
+                    file.write(document_content)
 
-        if export_mode in (
+        if project_config.is_feature_activated(
+            ProjectFeature.STANDALONE_DOCUMENT_SCREEN
+        ) or export_mode in (
             ExportMode.STANDALONE,
             ExportMode.DOCTREE_AND_STANDALONE,
         ):
@@ -266,3 +291,15 @@ class HTMLGenerator:
                 file.write(document_content_with_embedded_assets)
 
         return document
+
+    @staticmethod
+    def export_document_tree(
+        *,
+        config: ExportCommandConfig,
+        traceability_index: TraceabilityIndex,
+    ):
+        output_file = os.path.join(config.output_html_root, "index.html")
+        writer = DocumentTreeHTMLGenerator()
+        output = writer.export(config, traceability_index=traceability_index)
+        with open(output_file, "w", encoding="utf8") as file:
+            file.write(output)
