@@ -1,10 +1,9 @@
-from typing import Optional
+from typing import Optional, Type, Union
 
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
 from strictdoc.backend.sdoc.models.requirement import (
     Requirement,
-    RequirementComment,
 )
 from strictdoc.backend.sdoc.models.section import FreeText
 from strictdoc.core.traceability_index import TraceabilityIndex
@@ -25,9 +24,12 @@ class MarkupRenderer:
         traceability_index: TraceabilityIndex,
         link_renderer: LinkRenderer,
         context_document: Optional[Document],
-    ):
-        assert isinstance(traceability_index, TraceabilityIndex)
-        assert isinstance(link_renderer, LinkRenderer)
+    ) -> "MarkupRenderer":
+        html_fragment_writer: Union[
+            Type[RstToHtmlFragmentWriter],
+            Type[HTMLFragmentWriter],
+            Type[TextToHtmlWriter],
+        ]
         if not markup or markup == "RST":
             html_fragment_writer = RstToHtmlFragmentWriter
         elif markup == "HTML":
@@ -48,10 +50,16 @@ class MarkupRenderer:
         link_renderer: LinkRenderer,
         context_document: Optional[Document],
     ):
+        assert isinstance(traceability_index, TraceabilityIndex)
+        assert isinstance(link_renderer, LinkRenderer)
+        assert context_document is None or isinstance(
+            context_document, Document
+        ), context_document
+
         self.fragment_writer = fragment_writer
         self.traceability_index = traceability_index
         self.link_renderer: LinkRenderer = link_renderer
-        self.context_document: Document = context_document
+        self.context_document: Optional[Document] = context_document
 
         self.cache = {}
         self.rationale_cache = {}
@@ -60,9 +68,26 @@ class MarkupRenderer:
         assert isinstance(requirement, Requirement)
         if requirement in self.cache:
             return self.cache[requirement]
-        output = self.fragment_writer.write(
-            requirement.get_statement_single_or_multiline()
-        )
+        output = self.fragment_writer.write(requirement.reserved_statement)
+        self.cache[requirement] = output
+
+        return output
+
+    def render_truncated_requirement_statement(self, requirement):
+        assert isinstance(requirement, Requirement), requirement
+        assert requirement.reserved_statement is not None
+
+        statement_to_render = requirement.reserved_statement
+        if len(statement_to_render) >= 255:
+            first_line_break_index = statement_to_render.find("\n\n")
+            if first_line_break_index != -1:
+                statement_to_render = statement_to_render[
+                    0:first_line_break_index
+                ]
+            else:
+                statement_to_render = statement_to_render[0:255]
+            statement_to_render += " <...>"
+        output = self.fragment_writer.write(statement_to_render)
         self.cache[requirement] = output
 
         return output
@@ -71,22 +96,16 @@ class MarkupRenderer:
         assert isinstance(requirement, Requirement)
         if requirement in self.rationale_cache:
             return self.rationale_cache[requirement]
-
-        output = self.fragment_writer.write(
-            requirement.get_rationale_single_or_multiline()
-        )
+        output = self.fragment_writer.write(requirement.rationale)
         self.rationale_cache[requirement] = output
-
         return output
 
     def render_comment(self, comment):
-        assert isinstance(comment, RequirementComment)
+        assert isinstance(comment, str)
         if comment in self.cache:
             return self.cache[comment]
-
-        output = self.fragment_writer.write(comment.get_comment())
+        output = self.fragment_writer.write(comment)
         self.cache[comment] = output
-
         return output
 
     def render_free_text(self, document_type, free_text):
@@ -110,3 +129,13 @@ class MarkupRenderer:
         self.cache[(document_type, free_text)] = output
 
         return output
+
+    def render_meta_value(self, meta_field_value):
+        assert isinstance(meta_field_value, str)
+        if meta_field_value in self.cache:
+            return self.cache[meta_field_value]
+
+        output = self.fragment_writer.write(meta_field_value)
+        self.cache[meta_field_value] = output
+
+        return output
