@@ -1,13 +1,18 @@
+"""
+This implementation is loosely based on:
+A non-blocking read on a subprocess.PIPE in Python,
+https://stackoverflow.com/a/4896288/598057
+TODO: Consider switching from subprocess to asyncio for starting a server.
+https://stackoverflow.com/a/68564737/598057
+"""
 import datetime
 import os
 import re
-
-# FIXME: select has no poll() on Windows! Find a portable implementation.
-import select
 import shutil
 import socket
 import subprocess
-from contextlib import closing
+from contextlib import ExitStack, closing
+from queue import Empty, Queue
 from threading import Thread
 from time import sleep
 from typing import Optional
@@ -15,9 +20,7 @@ from typing import Optional
 import psutil
 from psutil import NoSuchProcess
 
-# Running selenium tests on GitHub Actions CI is considerably slower.
-# Passing the flag via env because pytest makes it hard to introduce an extra
-# command-line argument when it is not used as a test fixture.
+from strictdoc.helpers.file_system import get_portable_temp_dir
 from tests.end2end.conftest import test_environment
 
 
@@ -27,7 +30,39 @@ class ReadTimeout(Exception):
         self.seconds_passed = round(seconds_passed, 2)
 
 
-class SDocTestServer:
+class ServerStderrReadThread(Thread):
+    def __init__(self, server: "SDocTestServer", process_stderr):
+        super().__init__()
+        self.server: SDocTestServer = server
+        self.process_stderr = process_stderr
+
+    def run(self):
+        # Iteration through the process_stderr.readline is blocking.
+        for line in iter(self.process_stderr.readline, b""):
+            self.server.stderr_queue.put(line)
+
+
+class TestStderrLogThread(Thread):
+    def __init__(self, server: "SDocTestServer"):
+        super().__init__()
+        self.server: SDocTestServer = server
+        self.stderr_queue = server.stderr_queue
+        self.done = False
+
+    def run(self):
+        stderr_log_file = self.server.log_file_err
+        while not self.done:
+            try:
+                line_bytes = self.stderr_queue.get(
+                    timeout=test_environment.poll_timeout_seconds
+                )
+            except Empty:
+                continue
+            stderr_log_file.write(line_bytes)
+            stderr_log_file.flush()
+
+
+class SDocTestServer:  # pylint: disable=too-many-instance-attributes
     @staticmethod
     def create(input_path: str):
         if os.path.isdir(input_path):
@@ -51,19 +86,40 @@ class SDocTestServer:
         assert os.path.isdir(input_path)
         self.path_to_tdoc_folder = input_path
         self.output_path: Optional[str] = output_path
-        self.process = None
         self.server_port: int = (
             SDocTestServer._get_test_server_port()
             if is_parallel_execution
             else 5112
         )
-        if not SDocTestServer.check_no_existing_connection(
+        if SDocTestServer.check_existing_connection(
             "127.0.0.1", self.server_port
         ):
             raise OSError(
                 "TestSDocServer: Cannot start a server because there is another"
                 f"server already running at the port: {self.server_port}."
             )
+        path_to_tmp_dir = get_portable_temp_dir()
+        self.path_to_out_log = os.path.join(
+            path_to_tmp_dir, f"strictdoc_server.{self.server_port}.out.log"
+        )
+        self.path_to_err_log = os.path.join(
+            path_to_tmp_dir, f"strictdoc_server.{self.server_port}.err.log"
+        )
+        if os.path.exists(self.path_to_out_log):
+            os.remove(self.path_to_out_log)
+        if os.path.exists(self.path_to_err_log):
+            os.remove(self.path_to_err_log)
+
+        # All of these below become initialized/used starting from run()
+        self.process = None
+        self.log_file_out = None
+        self.log_file_err = None
+        self.stderr_queue = Queue()
+        self.exit_stack = ExitStack()
+        self.server_stderr_capture_thread: Optional[
+            ServerStderrReadThread
+        ] = None
+        self.test_stderr_log_thread: Optional[TestStderrLogThread] = None
 
     def __enter__(self):
         self.run()
@@ -94,30 +150,37 @@ class SDocTestServer:
                 ]
             )
 
-        temp_file = open(  # pylint: disable=consider-using-with
-            f"/tmp/strictdoc_server.{self.server_port}.out.log",
-            "w",
-            encoding="utf8",
+        self.log_file_out = open(  # pylint: disable=consider-using-with
+            self.path_to_out_log, "wb"
         )
+        self.log_file_err = open(  # pylint: disable=consider-using-with
+            self.path_to_err_log, "wb"
+        )
+        self.exit_stack.enter_context(self.log_file_out)
+        self.exit_stack.enter_context(self.log_file_err)
 
         process = subprocess.Popen(  # pylint: disable=consider-using-with
-            args, stdout=temp_file.fileno(), stderr=subprocess.PIPE, shell=False
+            args,
+            stdout=self.log_file_out.fileno(),
+            stderr=subprocess.PIPE,
+            shell=False,
         )
         self.process = process
 
-        # A non-blocking read on a subprocess.PIPE in Python
-        # https://stackoverflow.com/a/59291466/598057
-        os.set_blocking(  # pylint: disable=no-member
-            process.stderr.fileno(), False
+        self.server_stderr_capture_thread = ServerStderrReadThread(
+            server=self,
+            process_stderr=process.stderr,
         )
+        self.server_stderr_capture_thread.start()
 
-        SDocTestServer.receive_expected_response(
-            server_process=process,
+        # Capture first startup lines.
+        self.capture_expected_server_stderr_response(
             expectations=["INFO:     Application startup complete."],
         )
-        SDocTestServer.continue_capturing_stderr(
-            server_process=process, server_port=self.server_port
-        )
+
+        # Continue writing captured stderr output to the log file.
+        self.test_stderr_log_thread = TestStderrLogThread(server=self)
+        self.test_stderr_log_thread.start()
 
         sleep(test_environment.warm_up_interval_seconds)
         print(  # noqa: T201
@@ -126,6 +189,16 @@ class SDocTestServer:
         )
 
     def close(self, *, exit_due_exception: Optional[Exception]) -> None:
+        assert isinstance(
+            self.server_stderr_capture_thread, ServerStderrReadThread
+        ), self.server_stderr_capture_thread
+
+        if self.test_stderr_log_thread is not None:
+            self.test_stderr_log_thread.done = True
+            self.test_stderr_log_thread.join()
+
+        self.exit_stack.close()
+
         if self.process is None:
             return
 
@@ -139,20 +212,14 @@ class SDocTestServer:
                 f"\n--- Captured Uvicorn stdout "
                 f"(last {last_lines_number} lines) ---\n"
             )
-            with open(
-                f"/tmp/strictdoc_server.{self.server_port}.out.log",
-                encoding="utf8",
-            ) as out_temp_file:
+            with open(self.path_to_out_log, encoding="utf8") as out_temp_file:
                 out_temp_file_lines = out_temp_file.readlines()[
                     -last_lines_number:
                 ]
                 print("".join(out_temp_file_lines))  # noqa: T201
             print("\n--- Captured Uvicorn stderr ---\n")  # noqa: T201
 
-            with open(
-                f"/tmp/strictdoc_server.{self.server_port}.err.log",
-                encoding="utf8",
-            ) as err_temp_file:
+            with open(self.path_to_err_log, encoding="utf8") as err_temp_file:
                 print(err_temp_file.read())  # noqa: T201
 
         try:
@@ -178,10 +245,27 @@ class SDocTestServer:
             "stopping server and worker processes: "
             f"{parent.pid} -> {child_processes_ids}"
         )
-        self.process.kill()
+        self.process.terminate()
         for process in child_processes:
             if process.is_running():
-                process.kill()
+                process.terminate()
+
+        start_time = datetime.datetime.now()
+        while True:
+            if not SDocTestServer.check_existing_connection(
+                "127.0.0.1", self.server_port
+            ):
+                break
+
+            check_time = datetime.datetime.now()
+            diff_time = (check_time - start_time).total_seconds()
+            if diff_time > float(test_environment.server_term_timeout):
+                raise OSError(
+                    "TestSDocServer: Sent SIGTERM to a server but could not"
+                    "wait until the server port is released: "
+                    f"{self.server_port}."
+                )
+            sleep(0.1)
 
     def get_host_and_port(self):
         return f"http://localhost:{self.server_port}"
@@ -197,18 +281,13 @@ class SDocTestServer:
         return server_port
 
     @staticmethod
-    def check_no_existing_connection(host, port):
+    def check_existing_connection(host, port):
         with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as sock:
             if sock.connect_ex((host, port)) == 0:
-                return False
-            return True
+                return True
+            return False
 
-    @staticmethod
-    def receive_expected_response(server_process, expectations):
-        poll = select.poll()  # pylint: disable=no-member
-        poll.register(
-            server_process.stderr, select.POLLIN  # pylint: disable=no-member
-        )  # pylint: disable=no-member
+    def capture_expected_server_stderr_response(self, expectations):
         received_input = []
 
         start_time = datetime.datetime.now()
@@ -220,11 +299,14 @@ class SDocTestServer:
                 if diff_time > float(test_environment.wait_timeout_seconds):
                     raise ReadTimeout(diff_time)
 
-                # TODO: it could be that just polling for WAIT_TIMEOUT
-                # is enough.
-                if poll.poll(test_environment.poll_timeout_milliseconds):
-                    line_bytes = server_process.stderr.readline()
-                    while len(expectations) > 0 and line_bytes:
+                try:
+                    line_bytes = self.stderr_queue.get(
+                        timeout=test_environment.poll_timeout_seconds
+                    )
+                    assert isinstance(line_bytes, bytes), line_bytes
+                    self.log_file_err.write(line_bytes)
+
+                    if len(expectations) > 0:
                         line_string = line_bytes.decode("utf-8")
                         current_expectation = expectations[0]
                         received_input.append(line_string)
@@ -232,7 +314,8 @@ class SDocTestServer:
                             current_expectation, f"{line_string.rstrip()}"
                         ):
                             expectations.pop(0)
-                        line_bytes = server_process.stderr.readline()
+                except Empty:
+                    pass
         except ReadTimeout as timeout_exception:
             print(  # noqa: T201
                 "\nFailed to get an expected response from the server within "
@@ -241,34 +324,3 @@ class SDocTestServer:
             received_lines = "".join(received_input)
             print(f"\n--- Received input ---\n\n{received_lines}")  # noqa: T201
             raise ReadTimeout(timeout_exception.seconds_passed) from None
-
-    @staticmethod
-    def enqueue_output(out, server_port: int):
-        assert isinstance(server_port, int)
-        # This solution also uses Queue but here it is not used.
-        # https://stackoverflow.com/a/4896288/598057
-        with open(
-            f"/tmp/strictdoc_server.{server_port}.err.log", "wb"
-        ) as temp_file:
-            poll = select.poll()  # pylint: disable=no-member
-            poll.register(out, select.POLLIN)  # pylint: disable=no-member
-
-            while True:
-                if poll.poll(1000):
-                    line_bytes = out.readline()
-                    while line_bytes:
-                        temp_file.write(line_bytes)
-                        line_bytes = out.readline()
-                    temp_file.flush()
-
-    @staticmethod
-    def continue_capturing_stderr(server_process, server_port: int):
-        thread = Thread(
-            target=SDocTestServer.enqueue_output,
-            args=(
-                server_process.stderr,
-                server_port,
-            ),
-        )
-        thread.daemon = True  # thread dies with the program
-        thread.start()
