@@ -4,4 +4,4 @@
 
 
 def hello_world():
-    print("hello world")
+    print("hello world")  # noqa: T201
