@@ -1,4 +1,4 @@
 def hello_world():
     # [REQ-001]
-    print("Hello world!")
+    print("Hello world!")  # noqa: T201
     # [/REQ-001]
