@@ -12,14 +12,10 @@ class DocumentBuilder:
 
     def add_requirement(self, uid):
         parent = self.document
-        # level = None
         statement = "System X shall do Y"
         statement_multiline = None
-        # status = None
         tags = None
-        # references = []
         title = "Requirement title"
-        # body = None
         rationale = None
         rationale_multiline = None
         comments = []
@@ -45,7 +41,9 @@ class DocumentBuilder:
         return requirement
 
     def add_requirement_parent(self, req_id, parent_req_id):
-        requirement = next(r for r in self.requirements if r.uid == req_id)
+        requirement = next(
+            r for r in self.requirements if r.reserved_uid == req_id
+        )
         assert requirement
 
         reference = ParentReqReference(requirement, parent_req_id)
