@@ -4,7 +4,9 @@ import shutil
 
 from fastapi.testclient import TestClient
 
+from strictdoc import environment
 from strictdoc.cli.cli_arg_parser import ServerCommandConfig
+from strictdoc.core.project_config import ProjectConfig
 from strictdoc.server.app import create_app
 
 PATH_TO_THIS_TEST_FOLDER = os.path.dirname(os.path.abspath(__file__))
@@ -15,11 +17,17 @@ def test_export_document_to_reqif():
     shutil.rmtree(PATH_TO_OUTPUT_FOLDER, ignore_errors=True)
 
     config = ServerCommandConfig(
+        environment=environment,
         input_path=PATH_TO_THIS_TEST_FOLDER,
         output_path=PATH_TO_OUTPUT_FOLDER,
         reload=False,
+        port=8001,
+    )
+    client = TestClient(
+        create_app(
+            server_config=config, project_config=ProjectConfig.default_config()
+        )
     )
-    client = TestClient(create_app(config=config))
     response = client.get("/02_export_document_to_reqif/sample.html")
     assert response.status_code == 200
 
